@@ -1,4 +1,5 @@
 from rest_framework.decorators import action
+from rest_framework.permissions import IsAuthenticated, AllowAny
 from rest_framework.response import Response
 
 from drf_auth_service.common.mixins import EBSModelViewSet
@@ -9,8 +10,9 @@ from drf_auth_service.settings import settings
 class ServiceViewSet(EBSModelViewSet):
     serializer_class = settings.SERIALIZERS.SERVICE_SERIALIZER
     queryset = Service.objects.all()
+    permission_classes = [IsAuthenticated]
 
-    @action(detail=True, methods=['GET', 'PATCH'])
+    @action(detail=True, methods=['GET', 'PATCH'], url_name='configs')
     def configs(self, request, *args, **kwargs):
         service = self.get_object()
 
@@ -27,3 +29,6 @@ class ServiceViewSet(EBSModelViewSet):
             Config.objects.bulk_update(configs, ['value'])
 
             return Response(request.data)
+
+    def perform_create(self, serializer):
+        return serializer.save()
