@@ -23,14 +23,6 @@ EMAIL_PASSWORD = getattr(django_settings, 'EMAIL_HOST_PASSWORD')
 EMAIL_USE_TLS = getattr(django_settings, 'EMAIL_USE_TLS')
 
 
-# TODO Auth
-# Delete by username
-# same serializer for register
-# patch to post restore and other actions
-# generate jwt with service secret token
-# return jwt on confirm
-
-
 class ObjDict(dict):
     def __getattribute__(self, item):
         try:
@@ -84,9 +76,8 @@ default_sso_settings = {
     "SERIALIZERS": ObjDict({
         "USER_RETURN_SERIALIZER": "drf_auth_service.users.serializers.ReturnUserBaseSerializer",
         "USER_SERIALIZER": "drf_auth_service.users.serializers.UserBaseSerializer",
-        "BLOCK_USER_SERIALIZER": "drf_auth_service.users.serializers.BockUserSerializer",
+        "BLOCK_USER_SERIALIZER": "drf_auth_service.users.serializers.BlockUserSerializer",
         "USER_CONFIRM_SERIALIZER": "drf_auth_service.users.serializers.UserConfirmSerializer",
-        "USER_IDENTIFIER": "drf_auth_service.users.serializers.UserIdentifierSerializer",
         "SOCIAL_RETURN_SERIALIZER": "drf_auth_service.socials.serializers.ReturnSocialSerializer",
         "SOCIAL_SERIALIZER": "drf_auth_service.socials.serializers.SocialSerializer",
         "SERVICE_SERIALIZER": "drf_auth_service.services.serializers.ServiceSerializer",
@@ -155,7 +146,8 @@ class Settings:
         except:
             pass
 
-    def _add_custom_schema_to_swagger(self):
+    @staticmethod
+    def _add_custom_schema_to_swagger():
         try:
             from drf_yasg import app_settings
             swagger_schema = getattr(getattr(django_settings, 'SWAGGER_SETTINGS', {}), 'DEFAULT_AUTO_SCHEMA_CLASS',
@@ -213,18 +205,32 @@ class Settings:
 
                         for dict_key, dict_value in val.items():
                             if not type(dict_value) == list:
-                                configs.append(Config(type='str', value=dict_value, key=dict_key,
-                                                      service=service))
+                                configs.append(Config(
+                                    type='str',
+                                    value=dict_value,
+                                    key=dict_key,
+                                    service=service
+                                ))
+
                     elif type(val) == list:
                         value = ''
                         for list_value in val:
                             value += f"{list_value},"
 
-                        configs.append(Config(type='str', value=value.rstrip(','), key=key,
-                                              service=service))
+                        configs.append(Config(
+                            type='str',
+                            value=value.rstrip(','),
+                            key=key,
+                            service=service
+                        ))
+
                     else:
-                        configs.append(Config(type=type(val).__name__, value=str(val), key=key,
-                                              service=service))
+                        configs.append(Config(
+                            type=type(val).__name__ if type(val) is not None else 'str',
+                            value=str(val),
+                            key=key,
+                            service=service
+                        ))
 
             Config.objects.bulk_create(configs)
 
