@@ -5,7 +5,6 @@ from rest_framework.exceptions import ValidationError
 from rest_framework.generics import get_object_or_404
 
 from drf_auth_service.models import ActivationCode
-from drf_auth_service.settings import User
 
 
 def validate_token_by_type(token, code_type):
@@ -20,11 +19,3 @@ def validate_token_by_type(token, code_type):
         raise ValidationError(dict(detail='Token expired'))
 
     return reset_password_token
-
-
-def validate_user(user_filter):
-    user = User.objects.filter(username=user_filter).first()
-    if user is None:
-        raise ValidationError('User does not exist')
-
-    return user
